function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

var revalidate = function revalidate(request, response) {
  try {
    var slug = request.query.slug;
    var secret = request.query.secret; // Validate secret.

    if (secret !== process.env.DRUPAL_PREVIEW_SECRET) {
      return Promise.resolve(response.status(401).json({
        message: 'Invalid secret.'
      }));
    } // Validate slug.


    if (!slug) {
      return Promise.resolve(response.status(400).json({
        message: 'Invalid slug.'
      }));
    } // Fix for home slug.


    if (slug === process.env.NEXT_PUBLIC_DRUPAL_FRONT_PAGE) {
      slug = '/';
    }

    return Promise.resolve(_catch(function () {
      return Promise.resolve(response.unstable_revalidate(slug)).then(function () {
        return response.json({});
      });
    }, function (error) {
      return response.status(404).json({
        message: error.message
      });
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

export { revalidate };
//# sourceMappingURL=index.esm.js.map
